pub trait Readable: RegisterSpec { }Expand description
Trait implemented by readable registers to enable the read method.
Registers marked with Writable can be also be modify’ed.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl Readable for AbbAdcCtrlSpec
read() method returns abb_adc_ctrl::R reader structure
impl Readable for AbbDacCtrlSpec
read() method returns abb_dac_ctrl::R reader structure
impl Readable for AbbEnCtrlSpec
read() method returns abb_en_ctrl::R reader structure
impl Readable for AbnorImskSpec
read() method returns abnor_imsk::R reader structure
impl Readable for AbnorIntrRawSpec
read() method returns abnor_intr_raw::R reader structure
impl Readable for AbnorIntrStatSpec
read() method returns abnor_intr_stat::R reader structure
impl Readable for AonCrgCkenCtlSpec
read() method returns aon_crg_cken_ctl::R reader structure
impl Readable for AonSoftRstCtlSpec
read() method returns aon_soft_rst_ctl::R reader structure
impl Readable for BaudCtlSpec
read() method returns baud_ctl::R reader structure
impl Readable for BcpuResetStsSpec
read() method returns bcpu_reset_sts::R reader structure
impl Readable for BusConfig1Spec
read() method returns bus_config1::R reader structure
impl Readable for BusConfig2Spec
read() method returns bus_config2::R reader structure
impl Readable for BusDmaAhbCtrlSpec
read() method returns bus_dma_ahb_ctrl::R reader structure
impl Readable for BusDmaCtrlSpec
read() method returns bus_dma_ctrl::R reader structure
impl Readable for BusDmaFlashSaddrSpec
read() method returns bus_dma_flash_saddr::R reader structure
impl Readable for BusDmaLenSpec
read() method returns bus_dma_len::R reader structure
impl Readable for BusDmaMemSaddrSpec
read() method returns bus_dma_mem_saddr::R reader structure
impl Readable for CfgCicFilterEnSpec
read() method returns cfg_cic_filter_en::R reader structure
impl Readable for CfgCicOsrSpec
read() method returns cfg_cic_osr::R reader structure
impl Readable for CfgDataSelSpec
read() method returns cfg_data_sel::R reader structure
impl Readable for CfgDcocIqCtrlSpec
read() method returns cfg_dcoc_iq_ctrl::R reader structure
impl Readable for CfgFreqBusdmacSpec
read() method returns cfg_freq_busdmac::R reader structure
impl Readable for CfgGainSpec
read() method returns cfg_gain::R reader structure
impl Readable for CfgLpfCtrlSpec
read() method returns cfg_lpf_ctrl::R reader structure
impl Readable for CfgOffsetSpec
read() method returns cfg_offset::R reader structure
impl Readable for CfgPaIdxCtrlSpec
read() method returns cfg_pa_idx_ctrl::R reader structure
impl Readable for CfgPpaCodeSpec
read() method returns cfg_ppa_code::R reader structure
impl Readable for CfgRadarCtrlSpec
read() method returns cfg_radar_ctrl::R reader structure
impl Readable for CfgRamCkenSpec
read() method returns cfg_ram_cken::R reader structure
impl Readable for CfgRamSelSpec
read() method returns cfg_ram_sel::R reader structure
impl Readable for CfgRfDiagMuxSpec
read() method returns cfg_rf_diag_mux::R reader structure
impl Readable for CfgRfManEnCtrlSpec
read() method returns cfg_rf_man_en_ctrl::R reader structure
impl Readable for CfgRxDoneAddrSpec
read() method returns cfg_rx_done_addr::R reader structure
impl Readable for CfgRxDoneStsSpec
read() method returns cfg_rx_done_sts::R reader structure
impl Readable for CfgRxEnSpec
read() method returns cfg_rx_en::R reader structure
impl Readable for CfgRxEndAddrSpec
read() method returns cfg_rx_end_addr::R reader structure
impl Readable for CfgRxStartAddrSpec
read() method returns cfg_rx_start_addr::R reader structure
impl Readable for CfgTempBankSelCtrlSpec
read() method returns cfg_temp_bank_sel_ctrl::R reader structure
impl Readable for CfgTempLockCtrlSpec
read() method returns cfg_temp_lock_ctrl::R reader structure
impl Readable for CfgTrxenCtrlSpec
read() method returns cfg_trxen_ctrl::R reader structure
impl Readable for CfgTxDoneAddrSpec
read() method returns cfg_tx_done_addr::R reader structure
impl Readable for CfgTxDoneStsSpec
read() method returns cfg_tx_done_sts::R reader structure
impl Readable for CfgTxEnSpec
read() method returns cfg_tx_en::R reader structure
impl Readable for CfgTxEndAddrSpec
read() method returns cfg_tx_end_addr::R reader structure
impl Readable for CfgTxStartAddrSpec
read() method returns cfg_tx_start_addr::R reader structure
impl Readable for CfgWlAdcMuxSpec
read() method returns cfg_wl_adc_mux::R reader structure
impl Readable for CfgWlphy2pktRxRamStsSpec
read() method returns cfg_wlphy2pkt_rx_ram_sts::R reader structure
impl Readable for CfgWlphy2pktTxRamStsSpec
read() method returns cfg_wlphy2pkt_tx_ram_sts::R reader structure
impl Readable for ChannHashStateValAddrSpec
read() method returns chann_hash_state_val_addr::R reader structure
impl Readable for ChannHashStateValSpec
read() method returns chann_hash_state_val::R reader structure
impl Readable for ChipResetSpec
read() method returns chip_reset::R reader structure
impl Readable for CkenCtl0Spec
read() method returns cken_ctl0::R reader structure
impl Readable for CkenCtl1Spec
read() method returns cken_ctl1::R reader structure
impl Readable for ClkSelSpec
read() method returns clk_sel::R reader structure
impl Readable for CmdAddrSpec
read() method returns cmd_addr::R reader structure
impl Readable for CmdConfigSpec
read() method returns cmd_config::R reader structure
impl Readable for CmdDatabuf0Spec
read() method returns cmd_databuf_0::R reader structure
impl Readable for CmdDatabuf1Spec
read() method returns cmd_databuf_1::R reader structure
impl Readable for CmdDatabuf2Spec
read() method returns cmd_databuf_2::R reader structure
impl Readable for CmdDatabuf3Spec
read() method returns cmd_databuf_3::R reader structure
impl Readable for CmdDatabuf4Spec
read() method returns cmd_databuf_4::R reader structure
impl Readable for CmdDatabuf5Spec
read() method returns cmd_databuf_5::R reader structure
impl Readable for CmdDatabuf6Spec
read() method returns cmd_databuf_6::R reader structure
impl Readable for CmdDatabuf7Spec
read() method returns cmd_databuf_7::R reader structure
impl Readable for CmdDatabuf8Spec
read() method returns cmd_databuf_8::R reader structure
impl Readable for CmdDatabuf9Spec
read() method returns cmd_databuf_9::R reader structure
impl Readable for CmdDatabuf10Spec
read() method returns cmd_databuf_10::R reader structure
impl Readable for CmdDatabuf11Spec
read() method returns cmd_databuf_11::R reader structure
impl Readable for CmdDatabuf12Spec
read() method returns cmd_databuf_12::R reader structure
impl Readable for CmdDatabuf13Spec
read() method returns cmd_databuf_13::R reader structure
impl Readable for CmdDatabuf14Spec
read() method returns cmd_databuf_14::R reader structure
impl Readable for CmdDatabuf15Spec
read() method returns cmd_databuf_15::R reader structure
impl Readable for CmdInsSpec
read() method returns cmd_ins::R reader structure
impl Readable for CmuFnpllSigSpec
read() method returns cmu_fnpll_sig::R reader structure
impl Readable for CmuNewCfg0Spec
read() method returns cmu_new_cfg0::R reader structure
impl Readable for CmuNewCfg1Spec
read() method returns cmu_new_cfg1::R reader structure
impl Readable for CtClrSpec
read() method returns ct_clr::R reader structure
impl Readable for CtSetSpec
read() method returns ct_set::R reader structure
impl Readable for DataSpec
read() method returns data::R reader structure
impl Readable for DataWidthSetSpec
read() method returns data_width_set::R reader structure
impl Readable for DivCtl0Spec
read() method returns div_ctl0::R reader structure
impl Readable for DivCtl3Spec
read() method returns div_ctl3::R reader structure
impl Readable for DivCtl4Spec
read() method returns div_ctl4::R reader structure
impl Readable for DivCtl5Spec
read() method returns div_ctl5::R reader structure
impl Readable for DivCtl7Spec
read() method returns div_ctl7::R reader structure
impl Readable for DivCtl9Spec
read() method returns div_ctl9::R reader structure
impl Readable for DivCtl10Spec
read() method returns div_ctl10::R reader structure
impl Readable for DivFraSpec
read() method returns div_fra::R reader structure
impl Readable for DivHSpec
read() method returns div_h::R reader structure
impl Readable for DivLSpec
read() method returns div_l::R reader structure
impl Readable for DmaSwAckSpec
read() method returns dma_sw_ack::R reader structure
impl Readable for DmacBurstReqSpec
read() method returns dmac_burst_req::R reader structure
impl Readable for DmacChnConfig_Spec
read() method returns dmac_chn_config_::R reader structure
impl Readable for DmacChnControl_Spec
read() method returns dmac_chn_control_::R reader structure
impl Readable for DmacConfigSpec
read() method returns dmac_config::R reader structure
impl Readable for DmacDAddr_Spec
read() method returns dmac_d_addr_::R reader structure
impl Readable for DmacEnChnsSpec
read() method returns dmac_en_chns::R reader structure
impl Readable for DmacIntClrSpec
read() method returns dmac_int_clr::R reader structure
impl Readable for DmacIntStSpec
read() method returns dmac_int_st::R reader structure
impl Readable for DmacLli_Spec
read() method returns dmac_lli_::R reader structure
impl Readable for DmacOriIntStSpec
read() method returns dmac_ori_int_st::R reader structure
impl Readable for DmacSAddr_Spec
read() method returns dmac_s_addr_::R reader structure
impl Readable for DmacSingleReqSpec
read() method returns dmac_single_req::R reader structure
impl Readable for DmacSyncSpec
read() method returns dmac_sync::R reader structure
impl Readable for EfuseAvddCtlSpec
read() method returns efuse_avdd_ctl::R reader structure
impl Readable for EfuseClkPeriodSpec
read() method returns efuse_clk_period::R reader structure
impl Readable for EfuseCtlDataSpec
read() method returns efuse_ctl_data::R reader structure
impl Readable for EfuseDataSpec
read() method returns efuse_data::R reader structure
impl Readable for EfuseStsSpec
read() method returns efuse_sts::R reader structure
impl Readable for EmGtModeSpec
read() method returns em_gt_mode::R reader structure
impl Readable for ExcepRoRgSpec
read() method returns excep_ro_rg::R reader structure
impl Readable for FarSpec
read() method returns far::R reader structure
impl Readable for FifoStatusSpec
read() method returns fifo_status::R reader structure
impl Readable for FifoThresholdSpec
read() method returns fifo_threshold::R reader structure
impl Readable for FlpctrlSpec
read() method returns flpctrl::R reader structure
impl Readable for FlpiacmpSpec
read() method returns flpiacmp::R reader structure
impl Readable for Flplacmp0Spec
read() method returns flplacmp0::R reader structure
impl Readable for Flplacmp1Spec
read() method returns flplacmp1::R reader structure
impl Readable for FlprmpSpec
read() method returns flprmp::R reader structure
impl Readable for GlobalConfigSpec
read() method returns global_config::R reader structure
impl Readable for Gpio00SelSpec
read() method returns gpio_00_sel::R reader structure
impl Readable for Gpio01SelSpec
read() method returns gpio_01_sel::R reader structure
impl Readable for Gpio02SelSpec
read() method returns gpio_02_sel::R reader structure
impl Readable for Gpio03SelSpec
read() method returns gpio_03_sel::R reader structure
impl Readable for Gpio04SelSpec
read() method returns gpio_04_sel::R reader structure
impl Readable for Gpio05SelSpec
read() method returns gpio_05_sel::R reader structure
impl Readable for Gpio06SelSpec
read() method returns gpio_06_sel::R reader structure
impl Readable for Gpio07SelSpec
read() method returns gpio_07_sel::R reader structure
impl Readable for Gpio08SelSpec
read() method returns gpio_08_sel::R reader structure
impl Readable for Gpio09SelSpec
read() method returns gpio_09_sel::R reader structure
impl Readable for Gpio10SelSpec
read() method returns gpio_10_sel::R reader structure
impl Readable for Gpio11SelSpec
read() method returns gpio_11_sel::R reader structure
impl Readable for Gpio12SelSpec
read() method returns gpio_12_sel::R reader structure
impl Readable for Gpio13SelSpec
read() method returns gpio_13_sel::R reader structure
impl Readable for Gpio14SelSpec
read() method returns gpio_14_sel::R reader structure
impl Readable for GpioIntDebounceSpec
read() method returns gpio_int_debounce::R reader structure
impl Readable for GpioIntDedgeSpec
read() method returns gpio_int_dedge::R reader structure
impl Readable for GpioIntEnSpec
read() method returns gpio_int_en::R reader structure
impl Readable for GpioIntMaskSpec
read() method returns gpio_int_mask::R reader structure
impl Readable for GpioIntPolaritySpec
read() method returns gpio_int_polarity::R reader structure
impl Readable for GpioIntRawSpec
read() method returns gpio_int_raw::R reader structure
impl Readable for GpioIntTypeSpec
read() method returns gpio_int_type::R reader structure
impl Readable for GpioIntrSpec
read() method returns gpio_intr::R reader structure
impl Readable for GpioSwOenSpec
read() method returns gpio_sw_oen::R reader structure
impl Readable for GpioSwOutSpec
read() method returns gpio_sw_out::R reader structure
impl Readable for HaltTxSpec
read() method returns halt_tx::R reader structure
impl Readable for HashChannRawIntEnSpec
read() method returns hash_chann_raw_int_en::R reader structure
impl Readable for HashChannRawIntSpec
read() method returns hash_chann_raw_int::R reader structure
impl Readable for HwCtlSpec
read() method returns hw_ctl::R reader structure
impl Readable for I2cComSpec
read() method returns i2c_com::R reader structure
impl Readable for I2cCtrlSpec
read() method returns i2c_ctrl::R reader structure
impl Readable for I2cFifostatusSpec
read() method returns i2c_fifostatus::R reader structure
impl Readable for I2cFtrperSpec
read() method returns i2c_ftrper::R reader structure
impl Readable for I2cIcrSpec
read() method returns i2c_icr::R reader structure
impl Readable for I2cRxcountSpec
read() method returns i2c_rxcount::R reader structure
impl Readable for I2cRxrSpec
read() method returns i2c_rxr::R reader structure
impl Readable for I2cRxtideSpec
read() method returns i2c_rxtide::R reader structure
impl Readable for I2cSclHSpec
read() method returns i2c_scl_h::R reader structure
impl Readable for I2cSclLSpec
read() method returns i2c_scl_l::R reader structure
impl Readable for I2cSrSpec
read() method returns i2c_sr::R reader structure
impl Readable for I2cTxcountSpec
read() method returns i2c_txcount::R reader structure
impl Readable for I2cTxrSpec
read() method returns i2c_txr::R reader structure
impl Readable for I2cTxtideSpec
read() method returns i2c_txtide::R reader structure
impl Readable for I2sBclkDivNumSpec
read() method returns i2s_bclk_div_num::R reader structure
impl Readable for I2sCrgSpec
read() method returns i2s_crg::R reader structure
impl Readable for I2sDivCfgSpec
read() method returns i2s_div_cfg::R reader structure
impl Readable for I2sFsDivNumSpec
read() method returns i2s_fs_div_num::R reader structure
impl Readable for I2sFsDivRatioNumSpec
read() method returns i2s_fs_div_ratio_num::R reader structure
impl Readable for InHashChnCtrlSpec
read() method returns in_hash_chn_ctrl::R reader structure
impl Readable for InHashChnDataLenSpec
read() method returns in_hash_chn_data_len::R reader structure
impl Readable for InHashChnKeyCtrlSpec
read() method returns in_hash_chn_key_ctrl::R reader structure
impl Readable for InHashChnNodeLengthSpec
read() method returns in_hash_chn_node_length::R reader structure
impl Readable for InHashChnNodeRdPointSpec
read() method returns in_hash_chn_node_rd_point::R reader structure
impl Readable for InHashChnNodeStartAddrHSpec
read() method returns in_hash_chn_node_start_addr_h::R reader structure
impl Readable for InHashChnNodeStartAddrLSpec
read() method returns in_hash_chn_node_start_addr_l::R reader structure
impl Readable for InHashChnNodeWrPointSpec
read() method returns in_hash_chn_node_wr_point::R reader structure
impl Readable for InSymChn0CtrlSpec
read() method returns in_sym_chn0_ctrl::R reader structure
impl Readable for InSymChn0Data0Spec
read() method returns in_sym_chn0_data0::R reader structure
impl Readable for InSymChn0Iv0Spec
read() method returns in_sym_chn0_iv0::R reader structure
impl Readable for InSymChn0Iv1Spec
read() method returns in_sym_chn0_iv1::R reader structure
impl Readable for InSymChn0Iv2Spec
read() method returns in_sym_chn0_iv2::R reader structure
impl Readable for InSymChn0Iv3Spec
read() method returns in_sym_chn0_iv3::R reader structure
impl Readable for InSymChn0IvDataCtrlSpec
read() method returns in_sym_chn0_iv_data_ctrl::R reader structure
impl Readable for InSymChn0KeyCtrlSpec
read() method returns in_sym_chn0_key_ctrl::R reader structure
impl Readable for InSymChn0SpecialCtrlSpec
read() method returns in_sym_chn0_special_ctrl::R reader structure
impl Readable for InSymChnCtrlSpec
read() method returns in_sym_chn_ctrl::R reader structure
impl Readable for InSymChnKeyCtrlSpec
read() method returns in_sym_chn_key_ctrl::R reader structure
impl Readable for InSymChnNodeLengthSpec
read() method returns in_sym_chn_node_length::R reader structure
impl Readable for InSymChnNodeRdPointSpec
read() method returns in_sym_chn_node_rd_point::R reader structure
impl Readable for InSymChnNodeStartAddrHSpec
read() method returns in_sym_chn_node_start_addr_h::R reader structure
impl Readable for InSymChnNodeStartAddrLSpec
read() method returns in_sym_chn_node_start_addr_l::R reader structure
impl Readable for InSymChnNodeWrPointSpec
read() method returns in_sym_chn_node_wr_point::R reader structure
impl Readable for InSymOutCtrlSpec
read() method returns in_sym_out_ctrl::R reader structure
impl Readable for IntMaskSpec
read() method returns int_mask::R reader structure
impl Readable for IntRawStatusSpec
read() method returns int_raw_status::R reader structure
impl Readable for IntStatusSpec
read() method returns int_status::R reader structure
impl Readable for IntclrSpec
read() method returns intclr::R reader structure
impl Readable for IntmaskSpec
read() method returns intmask::R reader structure
impl Readable for IntrEnSpec
read() method returns intr_en::R reader structure
impl Readable for IntrIdSpec
read() method returns intr_id::R reader structure
impl Readable for IntrStatSpec
read() method returns intr_stat::R reader structure
impl Readable for IntrStatusSpec
read() method returns intr_status::R reader structure
impl Readable for IntstatusSpec
read() method returns intstatus::R reader structure
impl Readable for IpAutoCgBypassSpec
read() method returns ip_auto_cg_bypass::R reader structure
impl Readable for KcAidspLockCmdSpec
read() method returns kc_aidsp_lock_cmd::R reader structure
impl Readable for KcErrorSpec
read() method returns kc_error::R reader structure
impl Readable for KcPcpuLockCmdSpec
read() method returns kc_pcpu_lock_cmd::R reader structure
impl Readable for KcRdLockStatusSpec
read() method returns kc_rd_lock_status::R reader structure
impl Readable for KcRdSlotNumSpec
read() method returns kc_rd_slot_num::R reader structure
impl Readable for KcReecpuFlushBusySpec
read() method returns kc_reecpu_flush_busy::R reader structure
impl Readable for KcReecpuLockCmdSpec
read() method returns kc_reecpu_lock_cmd::R reader structure
impl Readable for KcTeecpuLockCmdSpec
read() method returns kc_teecpu_lock_cmd::R reader structure
impl Readable for KdfErrorSpec
read() method returns kdf_error::R reader structure
impl Readable for KlAlarmInfoSpec
read() method returns kl_alarm_info::R reader structure
impl Readable for KlClrCtrlSpec
read() method returns kl_clr_ctrl::R reader structure
impl Readable for KlComCtrlSpec
read() method returns kl_com_ctrl::R reader structure
impl Readable for KlComLockInfoSpec
read() method returns kl_com_lock_info::R reader structure
impl Readable for KlComLockStatusSpec
read() method returns kl_com_lock_status::R reader structure
impl Readable for KlComStatusSpec
read() method returns kl_com_status::R reader structure
impl Readable for KlDataIn1Spec
read() method returns kl_data_in_1::R reader structure
impl Readable for KlDataIn2Spec
read() method returns kl_data_in_2::R reader structure
impl Readable for KlDataIn3Spec
read() method returns kl_data_in_3::R reader structure
impl Readable for KlErrorSpec
read() method returns kl_error::R reader structure
impl Readable for KlIntEnSpec
read() method returns kl_int_en::R reader structure
impl Readable for KlIntRawSpec
read() method returns kl_int_raw::R reader structure
impl Readable for KlIntSpec
read() method returns kl_int::R reader structure
impl Readable for KlKeyAddrSpec
read() method returns kl_key_addr::R reader structure
impl Readable for KlKeyCfgSpec
read() method returns kl_key_cfg::R reader structure
impl Readable for KlKeySecCfgSpec
read() method returns kl_key_sec_cfg::R reader structure
impl Readable for KlLockCtrlSpec
read() method returns kl_lock_ctrl::R reader structure
impl Readable for KlStateSpec
read() method returns kl_state::R reader structure
impl Readable for LeaDfxInfoSpec
read() method returns lea_dfx_info::R reader structure
impl Readable for LeaIvVldSpec
read() method returns lea_iv_vld::R reader structure
impl Readable for LeaLpEnSpec
read() method returns lea_lp_en::R reader structure
impl Readable for LeftRxSpec
read() method returns left_rx::R reader structure
impl Readable for LeftTxSpec
read() method returns left_tx::R reader structure
impl Readable for LineStatusSpec
read() method returns line_status::R reader structure
impl Readable for LsadcCtrl0Spec
read() method returns lsadc_ctrl_0::R reader structure
impl Readable for LsadcCtrl1Spec
read() method returns lsadc_ctrl_1::R reader structure
impl Readable for LsadcCtrl2Spec
read() method returns lsadc_ctrl_2::R reader structure
impl Readable for LsadcCtrl3Spec
read() method returns lsadc_ctrl_3::R reader structure
impl Readable for LsadcCtrl4Spec
read() method returns lsadc_ctrl_4::R reader structure
impl Readable for LsadcCtrl6Spec
read() method returns lsadc_ctrl_6::R reader structure
impl Readable for LsadcCtrl7Spec
read() method returns lsadc_ctrl_7::R reader structure
impl Readable for LsadcCtrl8Spec
read() method returns lsadc_ctrl_8::R reader structure
impl Readable for LsadcCtrl9Spec
read() method returns lsadc_ctrl_9::R reader structure
impl Readable for LsadcCtrl11Spec
read() method returns lsadc_ctrl_11::R reader structure
impl Readable for LsadcCtrl12Spec
read() method returns lsadc_ctrl_12::R reader structure
impl Readable for McpuResetStsSpec
read() method returns mcpu_reset_sts::R reader structure
impl Readable for ModeSpec
read() method returns mode::R reader structure
impl Readable for ModemCtlSpec
read() method returns modem_ctl::R reader structure
impl Readable for ModemStatusSpec
read() method returns modem_status::R reader structure
impl Readable for NmiIntSpec
read() method returns nmi_int::R reader structure
impl Readable for OutSymChanRawLastNodeIntSpec
read() method returns out_sym_chan_raw_last_node_int::R reader structure
impl Readable for OutSymChnNodeLengthSpec
read() method returns out_sym_chn_node_length::R reader structure
impl Readable for OutSymChnNodeRdPointSpec
read() method returns out_sym_chn_node_rd_point::R reader structure
impl Readable for OutSymChnNodeStartAddrHSpec
read() method returns out_sym_chn_node_start_addr_h::R reader structure
impl Readable for OutSymChnNodeStartAddrLSpec
read() method returns out_sym_chn_node_start_addr_l::R reader structure
impl Readable for OutSymChnNodeWrPointSpec
read() method returns out_sym_chn_node_wr_point::R reader structure
impl Readable for PadGpio00CtrlSpec
read() method returns pad_gpio_00_ctrl::R reader structure
impl Readable for PadGpio01CtrlSpec
read() method returns pad_gpio_01_ctrl::R reader structure
impl Readable for PadGpio02CtrlSpec
read() method returns pad_gpio_02_ctrl::R reader structure
impl Readable for PadGpio03CtrlSpec
read() method returns pad_gpio_03_ctrl::R reader structure
impl Readable for PadGpio04CtrlSpec
read() method returns pad_gpio_04_ctrl::R reader structure
impl Readable for PadGpio05CtrlSpec
read() method returns pad_gpio_05_ctrl::R reader structure
impl Readable for PadGpio06CtrlSpec
read() method returns pad_gpio_06_ctrl::R reader structure
impl Readable for PadGpio07CtrlSpec
read() method returns pad_gpio_07_ctrl::R reader structure
impl Readable for PadGpio08CtrlSpec
read() method returns pad_gpio_08_ctrl::R reader structure
impl Readable for PadGpio09CtrlSpec
read() method returns pad_gpio_09_ctrl::R reader structure
impl Readable for PadGpio10CtrlSpec
read() method returns pad_gpio_10_ctrl::R reader structure
impl Readable for PadGpio11CtrlSpec
read() method returns pad_gpio_11_ctrl::R reader structure
impl Readable for PadGpio12CtrlSpec
read() method returns pad_gpio_12_ctrl::R reader structure
impl Readable for PadGpio13CtrlSpec
read() method returns pad_gpio_13_ctrl::R reader structure
impl Readable for PadGpio14CtrlSpec
read() method returns pad_gpio_14_ctrl::R reader structure
impl Readable for PadSfcClkCtrlSpec
read() method returns pad_sfc_clk_ctrl::R reader structure
impl Readable for PadSfcCsnCtrlSpec
read() method returns pad_sfc_csn_ctrl::R reader structure
impl Readable for PadSfcIo0CtrlSpec
read() method returns pad_sfc_io0_ctrl::R reader structure
impl Readable for PadSfcIo1CtrlSpec
read() method returns pad_sfc_io1_ctrl::R reader structure
impl Readable for PadSfcIo2CtrlSpec
read() method returns pad_sfc_io2_ctrl::R reader structure
impl Readable for PadSfcIo3CtrlSpec
read() method returns pad_sfc_io3_ctrl::R reader structure
impl Readable for PadUart0RxdCtrlSpec
read() method returns pad_uart0_rxd_ctrl::R reader structure
impl Readable for PadUart0TxdCtrlSpec
read() method returns pad_uart0_txd_ctrl::R reader structure
impl Readable for PadUart1RxdCtrlSpec
read() method returns pad_uart1_rxd_ctrl::R reader structure
impl Readable for PadUart1TxdCtrlSpec
read() method returns pad_uart1_txd_ctrl::R reader structure
impl Readable for PkeAlarmStatusSpec
read() method returns pke_alarm_status::R reader structure
impl Readable for PkeBusySpec
read() method returns pke_busy::R reader structure
impl Readable for PkeDramClrSpec
read() method returns pke_dram_clr::R reader structure
impl Readable for PkeDramMaskSpec
read() method returns pke_dram_mask::R reader structure
impl Readable for PkeFailureFlagSpec
read() method returns pke_failure_flag::R reader structure
impl Readable for PkeInstr0Spec
read() method returns pke_instr0::R reader structure
impl Readable for PkeInstr1Spec
read() method returns pke_instr1::R reader structure
impl Readable for PkeInstrAddrHigSpec
read() method returns pke_instr_addr_hig::R reader structure
impl Readable for PkeInstrAddrLowSpec
read() method returns pke_instr_addr_low::R reader structure
impl Readable for PkeInstrLenSpec
read() method returns pke_instr_len::R reader structure
impl Readable for PkeInstrRdySpec
read() method returns pke_instr_rdy::R reader structure
impl Readable for PkeIntEnableSpec
read() method returns pke_int_enable::R reader structure
impl Readable for PkeIntNomaskStatusSpec
read() method returns pke_int_nomask_status::R reader structure
impl Readable for PkeLockCtrlSpec
read() method returns pke_lock_ctrl::R reader structure
impl Readable for PkeLockStatusSpec
read() method returns pke_lock_status::R reader structure
impl Readable for PkeMaskRngCfgSpec
read() method returns pke_mask_rng_cfg::R reader structure
impl Readable for PkeMontPara0Spec
read() method returns pke_mont_para0::R reader structure
impl Readable for PkeMontPara1Spec
read() method returns pke_mont_para1::R reader structure
impl Readable for PkeNoiseEnSpec
read() method returns pke_noise_en::R reader structure
impl Readable for PkeStartSpec
read() method returns pke_start::R reader structure
impl Readable for PkeWorkLenSpec
read() method returns pke_work_len::R reader structure
impl Readable for PwmAbnorState0Spec
read() method returns pwm_abnor_state0::R reader structure
impl Readable for PwmAbnorState1Spec
read() method returns pwm_abnor_state1::R reader structure
impl Readable for PwmDmaEnSpec
read() method returns pwm_dma_en::R reader structure
impl Readable for PwmDutyH0Spec
read() method returns pwm_duty_h0::R reader structure
impl Readable for PwmDutyH1Spec
read() method returns pwm_duty_h1::R reader structure
impl Readable for PwmDutyH2Spec
read() method returns pwm_duty_h2::R reader structure
impl Readable for PwmDutyH3Spec
read() method returns pwm_duty_h3::R reader structure
impl Readable for PwmDutyH4Spec
read() method returns pwm_duty_h4::R reader structure
impl Readable for PwmDutyH5Spec
read() method returns pwm_duty_h5::R reader structure
impl Readable for PwmDutyH6Spec
read() method returns pwm_duty_h6::R reader structure
impl Readable for PwmDutyH7Spec
read() method returns pwm_duty_h7::R reader structure
impl Readable for PwmDutyL0Spec
read() method returns pwm_duty_l0::R reader structure
impl Readable for PwmDutyL1Spec
read() method returns pwm_duty_l1::R reader structure
impl Readable for PwmDutyL2Spec
read() method returns pwm_duty_l2::R reader structure
impl Readable for PwmDutyL3Spec
read() method returns pwm_duty_l3::R reader structure
impl Readable for PwmDutyL4Spec
read() method returns pwm_duty_l4::R reader structure
impl Readable for PwmDutyL5Spec
read() method returns pwm_duty_l5::R reader structure
impl Readable for PwmDutyL6Spec
read() method returns pwm_duty_l6::R reader structure
impl Readable for PwmDutyL7Spec
read() method returns pwm_duty_l7::R reader structure
impl Readable for PwmEn0Spec
read() method returns pwm_en0::R reader structure
impl Readable for PwmEn1Spec
read() method returns pwm_en1::R reader structure
impl Readable for PwmEn2Spec
read() method returns pwm_en2::R reader structure
impl Readable for PwmEn3Spec
read() method returns pwm_en3::R reader structure
impl Readable for PwmEn4Spec
read() method returns pwm_en4::R reader structure
impl Readable for PwmEn5Spec
read() method returns pwm_en5::R reader structure
impl Readable for PwmEn6Spec
read() method returns pwm_en6::R reader structure
impl Readable for PwmEn7Spec
read() method returns pwm_en7::R reader structure
impl Readable for PwmFreqH0Spec
read() method returns pwm_freq_h0::R reader structure
impl Readable for PwmFreqH1Spec
read() method returns pwm_freq_h1::R reader structure
impl Readable for PwmFreqH2Spec
read() method returns pwm_freq_h2::R reader structure
impl Readable for PwmFreqH3Spec
read() method returns pwm_freq_h3::R reader structure
impl Readable for PwmFreqH4Spec
read() method returns pwm_freq_h4::R reader structure
impl Readable for PwmFreqH5Spec
read() method returns pwm_freq_h5::R reader structure
impl Readable for PwmFreqH6Spec
read() method returns pwm_freq_h6::R reader structure
impl Readable for PwmFreqH7Spec
read() method returns pwm_freq_h7::R reader structure
impl Readable for PwmFreqL0Spec
read() method returns pwm_freq_l0::R reader structure
impl Readable for PwmFreqL1Spec
read() method returns pwm_freq_l1::R reader structure
impl Readable for PwmFreqL2Spec
read() method returns pwm_freq_l2::R reader structure
impl Readable for PwmFreqL3Spec
read() method returns pwm_freq_l3::R reader structure
impl Readable for PwmFreqL4Spec
read() method returns pwm_freq_l4::R reader structure
impl Readable for PwmFreqL5Spec
read() method returns pwm_freq_l5::R reader structure
impl Readable for PwmFreqL6Spec
read() method returns pwm_freq_l6::R reader structure
impl Readable for PwmFreqL7Spec
read() method returns pwm_freq_l7::R reader structure
impl Readable for PwmIntMaskSpec
read() method returns pwm_int_mask::R reader structure
impl Readable for PwmOenCfg0Spec
read() method returns pwm_oen_cfg0::R reader structure
impl Readable for PwmOenCfg1Spec
read() method returns pwm_oen_cfg1::R reader structure
impl Readable for PwmOenCfg2Spec
read() method returns pwm_oen_cfg2::R reader structure
impl Readable for PwmOenCfg3Spec
read() method returns pwm_oen_cfg3::R reader structure
impl Readable for PwmOenCfg4Spec
read() method returns pwm_oen_cfg4::R reader structure
impl Readable for PwmOenCfg5Spec
read() method returns pwm_oen_cfg5::R reader structure
impl Readable for PwmOenCfg6Spec
read() method returns pwm_oen_cfg6::R reader structure
impl Readable for PwmOenCfg7Spec
read() method returns pwm_oen_cfg7::R reader structure
impl Readable for PwmOffsetH0Spec
read() method returns pwm_offset_h0::R reader structure
impl Readable for PwmOffsetH1Spec
read() method returns pwm_offset_h1::R reader structure
impl Readable for PwmOffsetH2Spec
read() method returns pwm_offset_h2::R reader structure
impl Readable for PwmOffsetH3Spec
read() method returns pwm_offset_h3::R reader structure
impl Readable for PwmOffsetH4Spec
read() method returns pwm_offset_h4::R reader structure
impl Readable for PwmOffsetH5Spec
read() method returns pwm_offset_h5::R reader structure
impl Readable for PwmOffsetH6Spec
read() method returns pwm_offset_h6::R reader structure
impl Readable for PwmOffsetH7Spec
read() method returns pwm_offset_h7::R reader structure
impl Readable for PwmOffsetL0Spec
read() method returns pwm_offset_l0::R reader structure
impl Readable for PwmOffsetL1Spec
read() method returns pwm_offset_l1::R reader structure
impl Readable for PwmOffsetL2Spec
read() method returns pwm_offset_l2::R reader structure
impl Readable for PwmOffsetL3Spec
read() method returns pwm_offset_l3::R reader structure
impl Readable for PwmOffsetL4Spec
read() method returns pwm_offset_l4::R reader structure
impl Readable for PwmOffsetL5Spec
read() method returns pwm_offset_l5::R reader structure
impl Readable for PwmOffsetL6Spec
read() method returns pwm_offset_l6::R reader structure
impl Readable for PwmOffsetL7Spec
read() method returns pwm_offset_l7::R reader structure
impl Readable for PwmPeriodVal0Spec
read() method returns pwm_period_val0::R reader structure
impl Readable for PwmPeriodVal1Spec
read() method returns pwm_period_val1::R reader structure
impl Readable for PwmPeriodVal2Spec
read() method returns pwm_period_val2::R reader structure
impl Readable for PwmPeriodVal3Spec
read() method returns pwm_period_val3::R reader structure
impl Readable for PwmPeriodVal4Spec
read() method returns pwm_period_val4::R reader structure
impl Readable for PwmPeriodVal5Spec
read() method returns pwm_period_val5::R reader structure
impl Readable for PwmPeriodVal6Spec
read() method returns pwm_period_val6::R reader structure
impl Readable for PwmPeriodVal7Spec
read() method returns pwm_period_val7::R reader structure
impl Readable for PwmPeriodcnt0Spec
read() method returns pwm_periodcnt0::R reader structure
impl Readable for PwmPeriodcnt1Spec
read() method returns pwm_periodcnt1::R reader structure
impl Readable for PwmPeriodcnt2Spec
read() method returns pwm_periodcnt2::R reader structure
impl Readable for PwmPeriodcnt3Spec
read() method returns pwm_periodcnt3::R reader structure
impl Readable for PwmPeriodcnt4Spec
read() method returns pwm_periodcnt4::R reader structure
impl Readable for PwmPeriodcnt5Spec
read() method returns pwm_periodcnt5::R reader structure
impl Readable for PwmPeriodcnt6Spec
read() method returns pwm_periodcnt6::R reader structure
impl Readable for PwmPeriodcnt7Spec
read() method returns pwm_periodcnt7::R reader structure
impl Readable for PwmPeriodloadFlag0Spec
read() method returns pwm_periodload_flag0::R reader structure
impl Readable for PwmPeriodloadFlag1Spec
read() method returns pwm_periodload_flag1::R reader structure
impl Readable for PwmPeriodloadFlag2Spec
read() method returns pwm_periodload_flag2::R reader structure
impl Readable for PwmPeriodloadFlag3Spec
read() method returns pwm_periodload_flag3::R reader structure
impl Readable for PwmPeriodloadFlag4Spec
read() method returns pwm_periodload_flag4::R reader structure
impl Readable for PwmPeriodloadFlag5Spec
read() method returns pwm_periodload_flag5::R reader structure
impl Readable for PwmPeriodloadFlag6Spec
read() method returns pwm_periodload_flag6::R reader structure
impl Readable for PwmPeriodloadFlag7Spec
read() method returns pwm_periodload_flag7::R reader structure
impl Readable for PwmPortity0Spec
read() method returns pwm_portity0::R reader structure
impl Readable for PwmPortity1Spec
read() method returns pwm_portity1::R reader structure
impl Readable for PwmPortity2Spec
read() method returns pwm_portity2::R reader structure
impl Readable for PwmPortity3Spec
read() method returns pwm_portity3::R reader structure
impl Readable for PwmPortity4Spec
read() method returns pwm_portity4::R reader structure
impl Readable for PwmPortity5Spec
read() method returns pwm_portity5::R reader structure
impl Readable for PwmPortity6Spec
read() method returns pwm_portity6::R reader structure
impl Readable for PwmPortity7Spec
read() method returns pwm_portity7::R reader structure
impl Readable for PwmSel0Spec
read() method returns pwm_sel0::R reader structure
impl Readable for PwmSel1Spec
read() method returns pwm_sel1::R reader structure
impl Readable for PwmSel2Spec
read() method returns pwm_sel2::R reader structure
impl Readable for PwmSel3Spec
read() method returns pwm_sel3::R reader structure
impl Readable for PwmStartclrcntEn0Spec
read() method returns pwm_startclrcnt_en0::R reader structure
impl Readable for PwmStartclrcntEn1Spec
read() method returns pwm_startclrcnt_en1::R reader structure
impl Readable for PwmStartclrcntEn2Spec
read() method returns pwm_startclrcnt_en2::R reader structure
impl Readable for PwmStartclrcntEn3Spec
read() method returns pwm_startclrcnt_en3::R reader structure
impl Readable for RamSwConflictClrSpec
read() method returns ram_sw_conflict_clr::R reader structure
impl Readable for RamSwConflictStSpec
read() method returns ram_sw_conflict_st::R reader structure
impl Readable for RamxSwConflictBaseAddrSpec
read() method returns ramx_sw_conflict_base_addr::R reader structure
impl Readable for RawIntrStatSpec
read() method returns raw_intr_stat::R reader structure
impl Readable for ReeHashCalcCtrlCheckErrSpec
read() method returns ree_hash_calc_ctrl_check_err::R reader structure
impl Readable for ReeHashCalcCtrlCheckErrStatusSpec
read() method returns ree_hash_calc_ctrl_check_err_status::R reader structure
impl Readable for ReeSymCalcCtrlCheckErrSpec
read() method returns ree_sym_calc_ctrl_check_err::R reader structure
impl Readable for ReeSymCalcCtrlCheckErrStatusSpec
read() method returns ree_sym_calc_ctrl_check_err_status::R reader structure
impl Readable for RegSysRstRecordSpec
read() method returns reg_sys_rst_record::R reader structure
impl Readable for RemapDstBaseSpec
read() method returns remap_dst_base::R reader structure
impl Readable for RemapLenSpec
read() method returns remap_len::R reader structure
impl Readable for RemapSrcBaseSpec
read() method returns remap_src_base::R reader structure
impl Readable for ResetCountSpec
read() method returns reset_count::R reader structure
impl Readable for RfAbbLdoSpec
read() method returns rf_abb_ldo::R reader structure
impl Readable for RfAddaIsoSpec
read() method returns rf_adda_iso::R reader structure
impl Readable for RfBtCbbDisSpec
read() method returns rf_bt_cbb_dis::R reader structure
impl Readable for RfLnaLdoSpec
read() method returns rf_lna_ldo::R reader structure
impl Readable for RfPllLdoSpec
read() method returns rf_pll_ldo::R reader structure
impl Readable for RfPllReferenceSpec
read() method returns rf_pll_reference::R reader structure
impl Readable for RfRxLdoSpec
read() method returns rf_rx_ldo::R reader structure
impl Readable for RfTxLdoSpec
read() method returns rf_tx_ldo::R reader structure
impl Readable for RfVcoLdoSpec
read() method returns rf_vco_ldo::R reader structure
impl Readable for RfWlCbbDisSpec
read() method returns rf_wl_cbb_dis::R reader structure
impl Readable for RfWlRegClkCtlSpec
read() method returns rf_wl_reg_clk_ctl::R reader structure
impl Readable for RfWlRegCmdFifoStsSpec
read() method returns rf_wl_reg_cmd_fifo_sts::R reader structure
impl Readable for RfWlRegCmdSoftRstnSpec
read() method returns rf_wl_reg_cmd_soft_rstn::R reader structure
impl Readable for RfWlRegSoftRstnSpec
read() method returns rf_wl_reg_soft_rstn::R reader structure
impl Readable for RightRxSpec
read() method returns right_rx::R reader structure
impl Readable for RightTxSpec
read() method returns right_tx::R reader structure
impl Readable for RkpCmdCfgSpec
read() method returns rkp_cmd_cfg::R reader structure
impl Readable for RkpIntEnableSpec
read() method returns rkp_int_enable::R reader structure
impl Readable for RkpIntSpec
read() method returns rkp_int::R reader structure
impl Readable for RkpLockSpec
read() method returns rkp_lock::R reader structure
impl Readable for RkpPbkdf2ValSpec
read() method returns rkp_pbkdf2_val::R reader structure
impl Readable for RkpRawIntSpec
read() method returns rkp_raw_int::R reader structure
impl Readable for RstSoftCfg0Spec
read() method returns rst_soft_cfg0::R reader structure
impl Readable for RstSoftCfg1Spec
read() method returns rst_soft_cfg1::R reader structure
impl Readable for RtcControlSpec
read() method returns rtc_control::R reader structure
impl Readable for RtcCurrentValueSpec
read() method returns rtc_current_value::R reader structure
impl Readable for RtcEoiSpec
read() method returns rtc_eoi::R reader structure
impl Readable for RtcIntStatusSpec
read() method returns rtc_int_status::R reader structure
impl Readable for RtcLoadCountSpec
read() method returns rtc_load_count::R reader structure
impl Readable for RxAmpduCountSpec
read() method returns rx_ampdu_count::R reader structure
impl Readable for RxFailedMpduCountSpec
read() method returns rx_failed_mpdu_count::R reader structure
impl Readable for RxFailedMpduInAmpduCountSpec
read() method returns rx_failed_mpdu_in_ampdu_count::R reader structure
impl Readable for RxFifoCntSpec
read() method returns rx_fifo_cnt::R reader structure
impl Readable for RxFifoWriteSpec
read() method returns rx_fifo_write::R reader structure
impl Readable for RxFilterControlSpec
read() method returns rx_filter_control::R reader structure
impl Readable for RxFilteredMpduCountSpec
read() method returns rx_filtered_mpdu_count::R reader structure
impl Readable for RxKeySearchFailureCountSpec
read() method returns rx_key_search_failure_count::R reader structure
impl Readable for RxMicFailureCountSpec
read() method returns rx_mic_failure_count::R reader structure
impl Readable for RxReplayFailureCountSpec
read() method returns rx_replay_failure_count::R reader structure
impl Readable for RxStaSpec
read() method returns rx_sta::R reader structure
impl Readable for RxSuccessMpduCountSpec
read() method returns rx_success_mpdu_count::R reader structure
impl Readable for RxSuccessMpduInAmpduCountSpec
read() method returns rx_success_mpdu_in_ampdu_count::R reader structure
impl Readable for SignedExtSpec
read() method returns signed_ext::R reader structure
impl Readable for SoftIntEnSpec
read() method returns soft_int_en::R reader structure
impl Readable for SoftIntStsSpec
read() method returns soft_int_sts::R reader structure
impl Readable for SoftRstMaskSpec
read() method returns soft_rst_mask::R reader structure
impl Readable for SpaccBusErrSpec
read() method returns spacc_bus_err::R reader structure
impl Readable for SpaccHashChnLockSpec
read() method returns spacc_hash_chn_lock::R reader structure
impl Readable for SpaccIeSpec
read() method returns spacc_ie::R reader structure
impl Readable for SpaccIntRawHashClearFinishSpec
read() method returns spacc_int_raw_hash_clear_finish::R reader structure
impl Readable for SpaccIntRawSymClrFinishSpec
read() method returns spacc_int_raw_sym_clr_finish::R reader structure
impl Readable for SpaccSymChnLockSpec
read() method returns spacc_sym_chn_lock::R reader structure
impl Readable for SpiBrsSpec
read() method returns spi_brs::R reader structure
impl Readable for SpiCtraSpec
read() method returns spi_ctra::R reader structure
impl Readable for SpiCtrbSpec
read() method returns spi_ctrb::R reader structure
impl Readable for SpiDcrSpec
read() method returns spi_dcr::R reader structure
impl Readable for SpiDrdlSpec
read() method returns spi_drdl::R reader structure
impl Readable for SpiDrnmSpec
read() method returns spi_drnm::R reader structure
impl Readable for SpiDtdlSpec
read() method returns spi_dtdl::R reader structure
impl Readable for SpiEnhctlSpec
read() method returns spi_enhctl::R reader structure
impl Readable for SpiErSpec
read() method returns spi_er::R reader structure
impl Readable for SpiIcrSpec
read() method returns spi_icr::R reader structure
impl Readable for SpiIdSpec
read() method returns spi_id::R reader structure
impl Readable for SpiInmarSpec
read() method returns spi_inmar::R reader structure
impl Readable for SpiInsrSpec
read() method returns spi_insr::R reader structure
impl Readable for SpiMcrSpec
read() method returns spi_mcr::R reader structure
impl Readable for SpiMsticrSpec
read() method returns spi_msticr::R reader structure
impl Readable for SpiRainsrSpec
read() method returns spi_rainsr::R reader structure
impl Readable for SpiRfficrSpec
read() method returns spi_rfficr::R reader structure
impl Readable for SpiRlrSpec
read() method returns spi_rlr::R reader structure
impl Readable for SpiRsdrSpec
read() method returns spi_rsdr::R reader structure
impl Readable for SpiRsvdSpec
read() method returns spi_rsvd::R reader structure
impl Readable for SpiRwlrSpec
read() method returns spi_rwlr::R reader structure
impl Readable for SpiRxoicrSpec
read() method returns spi_rxoicr::R reader structure
impl Readable for SpiSlenrSpec
read() method returns spi_slenr::R reader structure
impl Readable for SpiTderSpec
read() method returns spi_tder::R reader structure
impl Readable for SpiTfoficrSpec
read() method returns spi_tfoficr::R reader structure
impl Readable for SpiTlrSpec
read() method returns spi_tlr::R reader structure
impl Readable for SpiTwlrSpec
read() method returns spi_twlr::R reader structure
impl Readable for SpiWsrSpec
read() method returns spi_wsr::R reader structure
impl Readable for StpCtlSpec
read() method returns stp_ctl::R reader structure
impl Readable for SymChannRawIntSpec
read() method returns sym_chann_raw_int::R reader structure
impl Readable for SysCtlIdSpec
read() method returns sys_ctl_id::R reader structure
impl Readable for SysRstRecord0Spec
read() method returns sys_rst_record_0::R reader structure
impl Readable for TcxoCount0Spec
read() method returns tcxo_count0::R reader structure
impl Readable for TcxoCount1Spec
read() method returns tcxo_count1::R reader structure
impl Readable for TcxoCount2Spec
read() method returns tcxo_count2::R reader structure
impl Readable for TcxoCount3Spec
read() method returns tcxo_count3::R reader structure
impl Readable for TcxoStatusSpec
read() method returns tcxo_status::R reader structure
impl Readable for TimerControlSpec
read() method returns timer_control::R reader structure
impl Readable for TimerCurrentValueSpec
read() method returns timer_current_value::R reader structure
impl Readable for TimerLoadCountSpec
read() method returns timer_load_count::R reader structure
impl Readable for TimerRawIntrSpec
read() method returns timer_raw_intr::R reader structure
impl Readable for TimingSpec
read() method returns timing::R reader structure
impl Readable for TrngDataStSpec
read() method returns trng_data_st::R reader structure
impl Readable for TrngFifoDataSpec
read() method returns trng_fifo_data::R reader structure
impl Readable for TrngFifoReadySpec
read() method returns trng_fifo_ready::R reader structure
impl Readable for TrngFroDivCntSpec
read() method returns trng_fro_div_cnt::R reader structure
impl Readable for TrngFroSampleClkSelSpec
read() method returns trng_fro_sample_clk_sel::R reader structure
impl Readable for TsensorAutoRefreshCfgSpec
read() method returns tsensor_auto_refresh_cfg::R reader structure
impl Readable for TsensorAutoRefreshPeriodSpec
read() method returns tsensor_auto_refresh_period::R reader structure
impl Readable for TsensorCtlIdSpec
read() method returns tsensor_ctl_id::R reader structure
impl Readable for TsensorCtrl1Spec
read() method returns tsensor_ctrl1::R reader structure
impl Readable for TsensorCtrlSpec
read() method returns tsensor_ctrl::R reader structure
impl Readable for TsensorOverTempSpec
read() method returns tsensor_over_temp::R reader structure
impl Readable for TsensorReg0Spec
read() method returns tsensor_reg0::R reader structure
impl Readable for TsensorReg1Spec
read() method returns tsensor_reg1::R reader structure
impl Readable for TsensorReg2Spec
read() method returns tsensor_reg2::R reader structure
impl Readable for TsensorReg3Spec
read() method returns tsensor_reg3::R reader structure
impl Readable for TsensorStsSpec
read() method returns tsensor_sts::R reader structure
impl Readable for TsensorTempHighLimitSpec
read() method returns tsensor_temp_high_limit::R reader structure
impl Readable for TsensorTempIntEnSpec
read() method returns tsensor_temp_int_en::R reader structure
impl Readable for TsensorTempIntStsSpec
read() method returns tsensor_temp_int_sts::R reader structure
impl Readable for TsensorTempLowLimitSpec
read() method returns tsensor_temp_low_limit::R reader structure
impl Readable for TxFifoCntSpec
read() method returns tx_fifo_cnt::R reader structure
impl Readable for TxFifoReadSpec
read() method returns tx_fifo_read::R reader structure
impl Readable for TxStaSpec
read() method returns tx_sta::R reader structure
impl Readable for Uart0RxdSelSpec
read() method returns uart0_rxd_sel::R reader structure
impl Readable for Uart0TxdSelSpec
read() method returns uart0_txd_sel::R reader structure
impl Readable for Uart1RxdSelSpec
read() method returns uart1_rxd_sel::R reader structure
impl Readable for Uart1TxdSelSpec
read() method returns uart1_txd_sel::R reader structure
impl Readable for UartCtlSpec
read() method returns uart_ctl::R reader structure
impl Readable for UartGpRegSpec
read() method returns uart_gp_reg::R reader structure
impl Readable for UartParameterSpec
read() method returns uart_parameter::R reader structure
impl Readable for Vap0AddressHeadsSpec
read() method returns vap0_address_heads::R reader structure
impl Readable for Vap0BssidTailSpec
read() method returns vap0_bssid_tail::R reader structure
impl Readable for Vap0StationAddressTailSpec
read() method returns vap0_station_address_tail::R reader structure
impl Readable for VersionSpec
read() method returns version::R reader structure
impl Readable for WdtCcvrEnSpec
read() method returns wdt_ccvr_en::R reader structure
impl Readable for WdtCntSpec
read() method returns wdt_cnt::R reader structure
impl Readable for WdtCrSpec
read() method returns wdt_cr::R reader structure
impl Readable for WdtEoiSpec
read() method returns wdt_eoi::R reader structure
impl Readable for WdtIntrSpec
read() method returns wdt_intr::R reader structure
impl Readable for WdtLoadSpec
read() method returns wdt_load::R reader structure
impl Readable for WdtLockSpec
read() method returns wdt_lock::R reader structure
impl Readable for WdtLpifStateSpec
read() method returns wdt_lpif_state::R reader structure
impl Readable for WdtRawIntrSpec
read() method returns wdt_raw_intr::R reader structure
impl Readable for WdtRestartSpec
read() method returns wdt_restart::R reader structure
impl Readable for WdtStatusSpec
read() method returns wdt_status::R reader structure
impl Readable for XoSignalSpec
read() method returns xo_signal::R reader structure